@@ -22,11 +22,11 @@ VSGDR::StaticData - Static data script support package for SSDT post-deployment
 
 =head1 VERSION
 
-Version 0.26
+Version 0.29
 
 =cut
 
-our $VERSION = '0.26';
+our $VERSION = '0.29';
 
 
 sub databaseName {
@@ -119,7 +119,7 @@ sub generateScript {
 
     no warnings;
     no warnings;
-    my $userName                        = $OSNAME eq 'MSWin32' ? Win32::LoginName : @{[getpwuid( $< )]}->[6]; $userName =~ s/,.*//;
+    my $userName                        = $OSNAME eq 'MSWin32' ? Win32::LoginName : ${[getpwuid( $< )]}->[6]; $userName =~ s/,.*//;
     use warnings;
     
     use warnings;                      
@@ -502,22 +502,32 @@ begin try
 end try
 begin catch
 
-    -- Rollback any locally begun transaction.  Don't fail the whole deployment if it's transactional.
-    -- If our transaction is the only one, then just rollback.
-    if \@\@trancount > 0 begin
+    -- if xact_state() = -1 then the transaction isn't recorded in \@\@trancount so check both
+    if \@\@trancount > 0 or xact_state() = -1 begin
+        if xact_state() = -1 
+            rollback; - we can't do anything else
+        -- Rollback any locally begun transaction to savepoint.  Don't fail the whole deployment if it's transactional.
+        -- If our transaction is the only one, then just rollback.
         if \@\@trancount > 1 begin
-            if \@localTransactionStarted is not null and \@localTransactionStarted = 1 
+            if \@localTransactionStarted is not null and \@localTransactionStarted = 1 begin
                 rollback transaction ${savePointName};
                 commit ; --  windback our local transaction completely
-            --else it's probably nothing to do with us.
+            end;
+            --else it's probably nothing to do with us. but we have to rollback anyway
+            else
+                rollback;
         end
-            else rollback
-    end
+        else begin
+            -- final check to see if we need to unwind the transaction
+            if \@\@trancount > 0
+                rollback;
+        end;
+    end;
 
-    print 'Deployment of ${combinedName} static data failed.  This script was rolled back.'
-    print error_message()
+    print 'Deployment of ${combinedName} static data failed.  This script was rolled back.';
+    print error_message();
     
-    ${set_IDENTITY_INSERT_OFF}
+    ${set_IDENTITY_INSERT_OFF};
 
 
 end catch
